states = [{'state': ['Alabama'], 'abbr': ['AL'], 'common': ['Ala']}, {'state': ['Alaska'], 'abbr': ['AK'], 'common': ['Alaska']}, {'state': ['Arizona'], 'abbr': ['AZ'], 'common': ['Ariz']}, {'state': ['Arkansas'], 'abbr': ['AR'], 'common': ['Ark']}, {'state': ['California'], 'abbr': ['CA'], 'common': ['Calif']}, {'state': ['Colorado'], 'abbr': ['CO'], 'common': ['Colo']}, {'state': ['Connecticut'], 'abbr': ['CT'], 'common': ['Conn']}, {'state': ['Delaware'], 'abbr': ['DE'], 'common': ['Del']}, {'state': ['Florida'], 'abbr': ['FL'], 'common': ['Fla']}, {'state': ['Georgia'], 'abbr': ['GA'], 'common': ['Ga']}, {'state': ['Hawaii'], 'abbr': ['HI'], 'common': ['Hawaii']}, {'state': ['Idaho'], 'abbr': ['ID'], 'common': ['Idaho']}, {'state': ['Illinois'], 'abbr': ['IL'], 'common': ['Ill']}, {'state': ['Indiana'], 'abbr': ['IN'], 'common': ['Ind']}, {'state': ['Iowa'], 'abbr': ['IA'], 'common': ['Iowa']}, {'state': ['Kansas'], 'abbr': ['KS'], 'common': ['Kans']}, {'state': ['Kentucky'], 'abbr': ['KY'], 'common': ['Ky']}, {'state': ['Louisiana'], 'abbr': ['LA'], 'common': ['La']}, {'state': ['Maine'], 'abbr': ['ME'], 'common': ['Maine']}, {'state': ['Maryland'], 'abbr': ['MD'], 'common': ['Md']}, {'state': ['Massachusetts'], 'abbr': ['MA'], 'common': ['Mass']}, {'state': ['Michigan'], 'abbr': ['MI'], 'common': ['Mich']}, {'state': ['Minnesota'], 'abbr': ['MN'], 'common': ['Minn']}, {'state': ['Mississippi'], 'abbr': ['MS'], 'common': ['Miss']}, {'state': ['Missouri'], 'abbr': ['MO'], 'common': ['Mo']}, {'state': ['Montana'], 'abbr': ['MT'], 'common': ['Mont']}, {'state': ['Nebraska'], 'abbr': ['NE'], 'common': ['Neb', 'Nebr']}, {'state': ['Nevada'], 'abbr': ['NV'], 'common': ['Nev']}, {'state': ['New Hampshire'], 'abbr': ['NH'], 'common': ['N.H']}, {'state': ['New Jersey'], 'abbr': ['NJ'], 'common': ['N.J']}, {'state': ['New Mexico'], 'abbr': ['NM'], 'common': ['N.Mex']}, {'state': ['New York'], 'abbr': ['NY'], 'common': ['N.Y']}, {'state': ['North Carolina'], 'abbr': ['NC'], 'common': ['N.C']}, {'state': ['North Dakota'], 'abbr': ['ND'], 'common': ['N.Dak']}, {'state': ['Ohio'], 'abbr': ['OH'], 'common': ['Ohio']}, {'state': ['Oklahoma'], 'abbr': ['OK'], 'common': ['Okla']}, {'state': ['Oregon'], 'abbr': ['OR'], 'common': ['Ore', 'Oreg']}, {'state': ['Pennsylvania'], 'abbr': ['PAs'], 'common': ['Pa']}, {'state': ['Rhode Island'], 'abbr': ['RI'], 'common': ['R.I']}, {'state': ['Vermont'], 'abbr': ['VT'], 'common': ['Vt']}, {'state': ['Virginia'], 'abbr': ['VA'], 'common': ['Va']}, {'state': ['Washington'], 'abbr': ['WA'], 'common': ['Wash']}, {'state': ['West Virginia'], 'abbr': ['WV'], 'common': ['W.Va']}, {'state': ['Wisconsin'], 'abbr': ['WI'], 'common': ['Wis', 'Wisc']}, {'state': ['Wyoming'], 'abbr': ['WY'], 'common': ['Wyo']}]

